.. _orion.db:

orion.db
========

.. currentmodule:: orion.db

Orion Database Explorer
~~~~~~~~~~~~~~~~~~~~~~~

.. autosummary::
   :toctree: api/

   OrionDBExplorer
   OrionDBExplorer.add_dataset
   OrionDBExplorer.get_datasets
   OrionDBExplorer.get_dataset
   OrionDBExplorer.add_signal
   OrionDBExplorer.add_signals
   OrionDBExplorer.get_signals
   OrionDBExplorer.get_signal
   OrionDBExplorer.add_template
   OrionDBExplorer.get_templates
   OrionDBExplorer.get_template
   OrionDBExplorer.add_pipeline
   OrionDBExplorer.get_pipelines
   OrionDBExplorer.get_pipeline
   OrionDBExplorer.add_experiment
   OrionDBExplorer.get_experiments
   OrionDBExplorer.get_experiment
   OrionDBExplorer.add_datarun
   OrionDBExplorer.get_dataruns
   OrionDBExplorer.get_datarun
   OrionDBExplorer.add_signalrun
   OrionDBExplorer.get_signalruns
   OrionDBExplorer.get_signalrun
   OrionDBExplorer.add_event
   OrionDBExplorer.get_events
   OrionDBExplorer.get_event
   OrionDBExplorer.add_annotation
   OrionDBExplorer.get_annotations
   OrionDBExplorer.get_annotation
